========================
Local Keychain Utilities
========================


.. image:: https://circleci.com/gh/apiology/local-keychain-utils.svg?style=svg
    :target: https://circleci.com/gh/apiology/local-keychain-utils

.. image:: https://img.shields.io/pypi/v/local-keychain-utils.svg
        :target: https://pypi.python.org/pypi/local-keychain-utils

.. image:: https://readthedocs.org/projects/local-keychain-utils/badge/?version=latest
        :target: https://local-keychain-utils.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

CLI tools to manipulate local keychain

* Free software: MIT license
* Documentation: https://local-keychain-utils.readthedocs.io.


Features
--------

* `local-keychain-store`: add a secret from the system keychain.
* `local-keychain-get`: retrieve a secret from the system keychain.
* `local-keychain-clear`: remove a secret from the system keychain.
